/* This file is automatically generated by buildconfig. */

#include "interface.h"
#include "methods.h"

#include "cnfs/cnfs.h"
#include "timecaf/timecaf.h"
#include "timehash/timehash.h"
#include "tradspool/tradspool.h"
#include "trash/trash.h"

STORAGE_METHOD storage_methods[5] = {
{
    "cnfs", TOKEN_CNFS,
    cnfs_init,
    cnfs_store,
    cnfs_retrieve,
    cnfs_next,
    cnfs_freearticle,
    cnfs_cancel,
    cnfs_ctl,
    cnfs_flushcacheddata,
    cnfs_printfiles,
    cnfs_explaintoken,
    cnfs_shutdown
},
{
    "timecaf", TOKEN_TIMECAF,
    timecaf_init,
    timecaf_store,
    timecaf_retrieve,
    timecaf_next,
    timecaf_freearticle,
    timecaf_cancel,
    timecaf_ctl,
    timecaf_flushcacheddata,
    timecaf_printfiles,
    timecaf_explaintoken,
    timecaf_shutdown
},
{
    "timehash", TOKEN_TIMEHASH,
    timehash_init,
    timehash_store,
    timehash_retrieve,
    timehash_next,
    timehash_freearticle,
    timehash_cancel,
    timehash_ctl,
    timehash_flushcacheddata,
    timehash_printfiles,
    timehash_explaintoken,
    timehash_shutdown
},
{
    "tradspool", TOKEN_TRADSPOOL,
    tradspool_init,
    tradspool_store,
    tradspool_retrieve,
    tradspool_next,
    tradspool_freearticle,
    tradspool_cancel,
    tradspool_ctl,
    tradspool_flushcacheddata,
    tradspool_printfiles,
    tradspool_explaintoken,
    tradspool_shutdown
},
{
    "trash", TOKEN_TRASH,
    trash_init,
    trash_store,
    trash_retrieve,
    trash_next,
    trash_freearticle,
    trash_cancel,
    trash_ctl,
    trash_flushcacheddata,
    trash_printfiles,
    trash_explaintoken,
    trash_shutdown
}
};

