/* This file is automatically generated by buildconfig. */

#ifndef METHODS_H
#define METHODS_H 1

#include "interface.h"

#define NUM_STORAGE_METHODS 5

#define TOKEN_CNFS                          3
#define TOKEN_TIMECAF                       4
#define TOKEN_TIMEHASH                      2
#define TOKEN_TRADSPOOL                     5
#define TOKEN_TRASH                         0

extern STORAGE_METHOD storage_methods[NUM_STORAGE_METHODS];

#endif /* METHODS_H */
